@@ -26,9 +26,9 @@ use Statistics::RserveClient::REXP::Vector;
 package Statistics::RserveClient::REXP::Logical;
 our @ISA = qw(Statistics::RserveClient::REXP::Vector);
 
-sub isInteger() { return Statistics::RserveClient::TRUE; }
-sub isNumeric() { return Statistics::RserveClient::TRUE; }
-sub isLogical() { return Statistics::RserveClient::TRUE; }
+sub isInteger() { return TRUE; }
+sub isNumeric() { return TRUE; }
+sub isLogical() { return TRUE; }
 
 sub getType() {
     return Statistics::RserveClient::XT_ARRAY_BOOL;
